@@ -32,3 +32,11 @@ class HKBaseClass:
         inst.hkClass = String(d["hkClass"])
 
         return inst
+
+    def __eq__(self, value: object):
+        if not isinstance(value, HKBaseClass):
+            raise NotImplementedError()
+        comparison = self.__dict__ == value.__dict__
+        if not comparison:
+            print(f"Class '{self.__class__.__name__}' doesn't match")
+        return comparison
